@@ -42,11 +42,11 @@ def file_decrypt(hub, fn, key):
 
 def data_decrypt(hub, fn, key):
     """
-    Decrypt the fiven file with the given key
+    Decrypt the given file with the given key
     """
     if not os.path.isfile(fn):
         raise FileNotFoundError(f"Account file {fn} not found")
     f = Fernet(key)
-    with open(fn, 'rb') as rfh:
+    with open(fn, "rb") as rfh:
         raw = f.decrypt(rfh.read())
     return msgpack.loads(raw)
