@@ -43,26 +43,25 @@ async def gather(hub, subs, profile):
         sub_data = {}
         if sub in hub.acct.SUB_PROFILES:
             continue
-        if not hasattr(hub, f'acct.{sub}'):
-            hub.log.debug(f"'{sub}' does not extend acct")
+        if not hasattr(hub, f"acct.{sub}"):
+            hub.log.trace(f"'{sub}' does not extend acct")
             continue
-        for plug in getattr(hub, f'acct.{sub}'):
-            hub.log.debug(f"Gathering account information for '{sub}'")
-            if "gather" in plug:
-                pdata = await plug.gather()
-            hub.pop.dicts.update(sub_data, pdata)
+        for plug in getattr(hub, f"acct.{sub}"):
+            hub.log.trace(f"Gathering account information for '{sub}.{plug.__name__}'")
+            if "gather" in plug._funcs:
+                p_data = await plug.gather() or {}
+                hub.pop.dicts.update(sub_data, p_data)
         hub.acct.SUB_PROFILES[sub] = sub_data
-
     for sub, sub_data in hub.acct.SUB_PROFILES.items():
-        hub.log.debug(f"Reading sub profile: {sub}")
+        hub.log.trace(f"Reading sub profile: {sub}")
         if profile in sub_data:
-            hub.log.debug("Found profile in sub_data: {profile}")
+            hub.log.trace(f"Found profile in sub_data: {profile}")
             hub.pop.dicts.update(ret, sub_data[profile])
     for sub in subs:
-        hub.log.debug(f"Reading acct profile: {sub}")
+        hub.log.trace(f"Reading acct profile: {sub}")
         if sub in hub.acct.PROFILES:
-            hub.log.debug(f"Found sub in acct.PROFILES: {profile}")
+            hub.log.trace(f"Found sub in acct.PROFILES: {profile}")
             if profile in hub.acct.PROFILES[sub]:
-                hub.log.debug(f"Found account in acct.PROFILES.{sub}: {profile}")
+                hub.log.trace(f"Found account in acct.PROFILES.{sub}: {profile}")
                 hub.pop.dicts.update(ret, hub.acct.PROFILES[sub][profile])
     return ret
